@@ -1,5 +1,5 @@
 package List::Objects::WithUtils::Array::Immutable;
-$List::Objects::WithUtils::Array::Immutable::VERSION = '2.018001';
+$List::Objects::WithUtils::Array::Immutable::VERSION = '2.019001';
 use strictures 1;
 
 require Role::Tiny;
@@ -11,8 +11,18 @@ Role::Tiny->apply_roles_to_package( __PACKAGE__,
   /,
 );
 
-use Exporter 'import';
+use Exporter ();
 our @EXPORT = 'immarray';
+
+sub import {
+  my $pkg = caller;
+  { no strict 'refs';
+    ${"${pkg}::a"} = ${"${pkg}::a"};
+    ${"${pkg}::b"} = ${"${pkg}::b"};
+  }
+  goto &Exporter::import
+}
+
 sub immarray { __PACKAGE__->new(@_) }
 
 1;
