@@ -1,5 +1,5 @@
 package List::Objects::WithUtils::Hash::Typed;
-$List::Objects::WithUtils::Hash::Typed::VERSION = '2.018001';
+$List::Objects::WithUtils::Hash::Typed::VERSION = '2.019001';
 use strictures 1;
 
 require Role::Tiny;
@@ -10,8 +10,17 @@ Role::Tiny->apply_roles_to_package( __PACKAGE__,
   /
 );
 
-use Exporter 'import';
+use Exporter ();
 our @EXPORT = 'hash_of';
+
+sub import {
+  my $pkg = caller;
+  { no strict 'refs';
+    ${"${pkg}::a"} = ${"${pkg}::a"}; ${"${pkg}::b"} = ${"${pkg}::b"};
+  }
+  goto &Exporter::import
+}
+
 sub hash_of { __PACKAGE__->new(@_) }
 
 1;
